#ifndef GET_HELPER_H
#define GET_HELPER_H

#include <libubox/blobmsg.h>
#include <libubus.h>
#include "common.h"
#include "libdmtree/dmbbf.h"

void handle_pending_signal(int sig);

int bbfdm_cmd_exec(struct dmctx *bbf_ctx, int cmd);

void bbf_init(struct dmctx *dm_ctx);
void bbf_cleanup(struct dmctx *dm_ctx);
void bbf_sub_init(struct dmctx *dm_ctx);
void bbf_sub_cleanup(struct dmctx *dm_ctx);
void bbf_commit();

#endif /* GET_HELPER_H */
